/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Prop, h, Event, Element, State, Watch } from '@stencil/core';
export class BciHeaderComponent {
  constructor() {
    /**
     * Control header styling for different view modes
     */
    this.mode = 'Normal';
    /**
     * Control if the settings icon should be visible
     */
    this.showSettingsIcon = false;
    /**
     * Feature toggle: If an Array with the breadcrumb link structure is set,
     * the breadcrumb will be rendered.
     */
    this.breadcrumbArray = null;
    /**
     * Control the visible of the breadcrumb during iframe scrolling
     */
    this.hideBreadcrumb = false;
    /**
     * Control what the title of the header should be
     */
    this.headerTitle = '';
    this.title = this.headerTitle;
    this.settingsIcon = this.showSettingsIcon;
    this.breadcrumbLinkList = null;
    this.easeOutBreadcrumb = this.hideBreadcrumb;
    this.styles = this.onModeChange();
  }
  onTitleChange(newValue) {
    this.title = newValue;
  }
  onSettingsIconChange(newValue) {
    this.settingsIcon = newValue;
  }
  onBreadcrumbChange(newValue) {
    try {
      this.breadcrumbLinkList = JSON.parse(newValue);
    }
    catch (e) {
      this.breadcrumbLinkList = null;
    }
  }
  onEaseOutBreadcrumbChange(newValue) {
    this.easeOutBreadcrumb = newValue;
  }
  onModeChange() {
    switch (this.mode) {
      case 'Maximized':
        return (this.styles = {
          maximized: true,
          'maximized-menu-open': false,
        });
      case 'MaximizedMenuOpen':
        return (this.styles = {
          maximized: true,
          'maximized-menu-open': true,
        });
      case 'Normal':
        return (this.styles = {
          maximized: false,
          'maximized-menu-open': false,
        });
    }
  }
  render() {
    return (h("header", { class: Object.assign({ 'bci-portal-header': true, 'no-breadcrumb': !this.breadcrumbArray || !!this.styles.maximized, 'hide-breadcrumb': !!(this.easeOutBreadcrumb && this.breadcrumbArray) }, this.styles) },
      this.styles.maximized && !this.styles['maximized-menu-open'] ? (h("bci-portal-header-maximized-burger-icon", null)) : (''),
      h("div", { class: "bci-portal-header-title_wrapper" },
        h("span", { class: Object.assign({ 'bci-portal-header-title': true }, this.styles) },
          h("span", null, this.title)),
        this.renderSettingsIcon()),
      this.styles.maximized ? (h("div", { class: { 'bci-portal-header-toolbar': true } },
        h("span", { onClick: () => this.closeFullscreenIconClicked.emit(), class: "bci-portal-header-fullscreen-exit bosch-ic bosch-ic-medium bosch-ic-fullscreen-exit bosch-ic-clickable" }))) : (h("div", { class: Object.assign({ 'bci-portal-header-toolbar': true }, this.styles) },
        h("span", { class: "bci-portal-header-menu-open bosch-ic bosch-ic-medium bosch-ic-my-brand-frame bosch-ic-clickable", onClick: () => {
            this.toggleHeaderMenu();
          } }),
        h("div", { class: "bci-portal-header-menu-wrapper" },
          h("span", { class: "bci-portal-header-menu-close bosch-ic bosch-ic-medium bosch-ic-close bosch-ic-clickable", onClick: () => {
              this.toggleHeaderMenu();
            } }),
          h("div", { class: "bci-portal-header-menu" },
            h("slot", null))))),
      this.generateBreadcrumb()));
  }
  renderSettingsIcon() {
    if (this.settingsIcon && !document.currentScript) {
      return (h("span", { onClick: () => this.settingsIconClicked.emit(), "data-test": "webcore.webcomponents.header.settings.span", id: "header-settings-icon", class: "bci-portal-header-settings-icon  \n                                  bosch-ic\n                                  bosch-ic-medium\n                                  bosch-ic-clickable\n                                  bosch-ic-settings" }));
    }
  }
  generateBreadcrumb() {
    if (this.breadcrumbLinkList && !document.currentScript && !this.styles.maximized) {
      let listItems = [];
      this.breadcrumbLinkList.forEach((link, index) => {
        const spanElement = index < this.breadcrumbLinkList.length - 1 ? h("span", { class: "bosch-ic bosch-ic-forward-right-small" }) : '';
        const linkElement = link.id ? (h("a", { href: "javascript:void(null);", role: "button", onClick: () => this.breadcrumbLinkClicked.emit(link.id), title: link.label }, link.label)) : (h("span", { class: "no-link", title: link.label }, link.label));
        listItems.push(h("span", null,
          linkElement,
          spanElement));
      });
      return h("div", { class: { breadcrumb: true } }, listItems);
    }
    else {
      return null;
    }
  }
  toggleHeaderMenu() {
    let menu = this.el.shadowRoot.querySelector('.bci-portal-header-menu-wrapper');
    menu.classList.toggle('open');
  }
  static get is() { return "bci-header"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["bci-header.component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["bci-header.component.css"]
  }; }
  static get properties() { return {
    "mode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "ViewModes",
        "resolved": "\"Maximized\" | \"MaximizedMenuOpen\" | \"Normal\"",
        "references": {
          "ViewModes": {
            "location": "import",
            "path": "./bci-header.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Control header styling for different view modes"
      },
      "attribute": "mode",
      "reflect": true,
      "defaultValue": "'Normal'"
    },
    "showSettingsIcon": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Control if the settings icon should be visible"
      },
      "attribute": "show-settings-icon",
      "reflect": true,
      "defaultValue": "false"
    },
    "breadcrumbArray": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Feature toggle: If an Array with the breadcrumb link structure is set,\nthe breadcrumb will be rendered."
      },
      "attribute": "breadcrumb-array",
      "reflect": true,
      "defaultValue": "null"
    },
    "hideBreadcrumb": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Control the visible of the breadcrumb during iframe scrolling"
      },
      "attribute": "hide-breadcrumb",
      "reflect": true,
      "defaultValue": "false"
    },
    "headerTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Control what the title of the header should be"
      },
      "attribute": "header-title",
      "reflect": true,
      "defaultValue": "''"
    }
  }; }
  static get states() { return {
    "title": {},
    "settingsIcon": {},
    "breadcrumbLinkList": {},
    "easeOutBreadcrumb": {},
    "styles": {}
  }; }
  static get events() { return [{
      "method": "settingsIconClicked",
      "name": "bci.portal.header.settingsIconClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "closeFullscreenIconClicked",
      "name": "bci.portal.header.closeFullscreenIconClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "breadcrumbLinkClicked",
      "name": "bci.portal.header.breadcrumbLinkClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "headerTitle",
      "methodName": "onTitleChange"
    }, {
      "propName": "showSettingsIcon",
      "methodName": "onSettingsIconChange"
    }, {
      "propName": "breadcrumbArray",
      "methodName": "onBreadcrumbChange"
    }, {
      "propName": "hideBreadcrumb",
      "methodName": "onEaseOutBreadcrumbChange"
    }, {
      "propName": "mode",
      "methodName": "onModeChange"
    }]; }
}

