/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, h, Prop, Event, Element, Host, Method } from '@stencil/core';
import { CollectionType } from './checkbox-collection.interface';
import { translate } from '../../utils/utils';
import { MDCCheckbox } from '@material/checkbox';
import { setLocale } from '../../utils/locale-store';
export class CheckboxCollection {
  constructor() {
    this.list = [];
    this.multiSelectionList = [];
  }
  async componentWillLoad() {
    await setLocale();
  }
  async reset() {
    this.el.shadowRoot.querySelectorAll(`input[type='checkbox']`).forEach((item) => (item['checked'] = false));
    this.multiSelectionList = [];
  }
  async setDefaultSelection() {
    if (this.type === CollectionType.Multi) {
      this.multiSelectionList = this.list.reduce((accumulator, currentItem, index) => {
        if (currentItem.label) {
          accumulator.push(currentItem.label);
          const checkbox = new MDCCheckbox(this.el.shadowRoot.getElementById(`multi-checkbox-${index}`).parentElement);
          checkbox.checked = currentItem.selected;
        }
        return accumulator;
      }, []);
      this.multiItemSelected.emit(this.multiSelectionList);
    }
    else {
      const index = this.list.findIndex((item) => item.selected);
      const checkbox = new MDCCheckbox(this.el.shadowRoot.getElementById(`single-checkbox-${index}`).parentElement);
      checkbox.checked = true;
      this.singleItemSelected.emit(this.list[index].label);
    }
  }
  multiItemSelectedHandler(event, filter) {
    if (event.target['checked']) {
      this.multiSelectionList.push(filter.label);
    }
    else {
      const i = this.multiSelectionList.findIndex((j) => j === filter.label);
      if (i > -1) {
        this.multiSelectionList.splice(i, 1);
      }
    }
    this.multiItemSelected.emit(this.multiSelectionList);
  }
  singleItemSelectHandler(event, filter) {
    if (event.target['checked']) {
      this.singleItemSelected.emit(filter.label);
    }
    // Unchecking other checkboxes in the collection
    this.el.shadowRoot.querySelectorAll('.single').forEach((item) => (item['checked'] = false));
    event.target['checked'] = true;
  }
  selectHandler(event, item, multipleSelection) {
    if (multipleSelection) {
      return this.multiItemSelectedHandler(event, item);
    }
    this.singleItemSelectHandler(event, item);
  }
  renderCheckbox(item, index, multipleSelection) {
    return (h("div", { "data-test": "webcore.webcomponents.checkbox-collection.checkbox-item", class: "mdc-form-field checkbox-item", part: multipleSelection ? '' : 'single-checkbox-item' },
      h("div", { class: "mdc-checkbox" },
        h("input", { "data-test": "webcore.webcomponents.checkbox-collection.checkbox-item.multiple-selection", type: "checkbox", class: 'mdc-checkbox__native-control ' + (multipleSelection ? 'multi' : 'single'), id: `${multipleSelection ? 'multi' : 'single'}-checkbox-${index}`, onClick: (event) => this.selectHandler(event, item, multipleSelection) }),
        h("div", { class: "mdc-checkbox__background" },
          h("svg", { class: "mdc-checkbox__checkmark", viewBox: "0 0 24 24" },
            h("path", { class: "mdc-checkbox__checkmark-path", fill: "none", d: "M1.73,12.91 8.1,19.28 22.79,4.59" })),
          h("div", { class: "mdc-checkbox__mixedmark" })),
        h("div", { class: "mdc-checkbox__ripple" })),
      h("label", { htmlFor: `${multipleSelection ? 'multi' : 'single'}-checkbox-${index}` }, translate(item.label))));
  }
  render() {
    const multipleSelection = this.type === CollectionType.Multi;
    return h(Host, null, this.list.map((item, index) => this.renderCheckbox(item, index, multipleSelection)));
  }
  static get is() { return "bci-checkbox-collection"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["checkbox-collection.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["checkbox-collection.css"]
  }; }
  static get properties() { return {
    "type": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "CollectionType",
        "resolved": "CollectionType.Multi | CollectionType.Single",
        "references": {
          "CollectionType": {
            "location": "import",
            "path": "./checkbox-collection.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "type",
      "reflect": false
    },
    "list": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "CheckboxItem[]",
        "resolved": "CheckboxItem[]",
        "references": {
          "CheckboxItem": {
            "location": "import",
            "path": "./checkbox-collection.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "[]"
    }
  }; }
  static get events() { return [{
      "method": "multiItemSelected",
      "name": "multiItemSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "singleItemSelected",
      "name": "singleItemSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }]; }
  static get methods() { return {
    "reset": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    },
    "setDefaultSelection": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          },
          "CheckboxItem": {
            "location": "import",
            "path": "./checkbox-collection.interface"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}

