/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/**
 * Copyright (C) 2021. Robert Bosch GmbH Copyright (C) 2021. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Prop, Watch } from '@stencil/core';
export class CheckboxInput {
  get internalIndication() {
    return this.indication
      ? {
        checked: this.indication === 'checked',
        indeterminate: this.indication === 'indeterminate',
      }
      : {
        checked: this.checked,
        indeterminate: this.indeterminate,
      };
  }
  onStateChange(newState) {
    this.indication = newState;
  }
  render() {
    const { checked, indeterminate } = this.internalIndication;
    return (h("div", { class: "mdc-form-field checkbox-input" },
      h("div", { class: "mdc-checkbox" },
        h("input", { "data-test": "webcore.webcomponents.checkbox-input.checkbox-input-event", type: "checkbox", class: "mdc-checkbox__native-control", id: this.checkboxId, checked: checked, indeterminate: indeterminate, onClick: (event) => this.handleClick(event) }),
        h("div", { class: "mdc-checkbox__background" },
          h("svg", { class: "mdc-checkbox__checkmark", viewBox: "0 0 24 24" },
            h("path", { class: "mdc-checkbox__checkmark-path", fill: "none", d: "M1.73,12.91 8.1,19.28 22.79,4.59" })),
          h("div", { class: "mdc-checkbox__mixedmark" })),
        h("div", { class: "mdc-checkbox__ripple" })),
      h("label", { htmlFor: this.checkboxId },
        h("slot", null))));
  }
  handleClick(event) {
    event.stopPropagation();
    const checked = event.target.checked;
    this.checkedChange.emit(checked);
    this.indicationChange.emit(checked ? 'checked' : 'unchecked');
  }
  static get is() { return "checkbox-input"; }
  static get originalStyleUrls() { return {
    "$": ["checkbox-input.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["checkbox-input.css"]
  }; }
  static get properties() { return {
    "checkboxId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "used as ID for the checkbox input"
          }],
        "text": ""
      },
      "attribute": "checkbox-id",
      "reflect": false
    },
    "checked": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "control's the checked state of the checkbox input"
          }],
        "text": ""
      },
      "attribute": "checked",
      "reflect": false
    },
    "indeterminate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "control's the indeterminate state of the checkbox input"
          }],
        "text": ""
      },
      "attribute": "indeterminate",
      "reflect": false
    },
    "indication": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "CheckboxIndication",
        "resolved": "\"checked\" | \"indeterminate\" | \"unchecked\"",
        "references": {
          "CheckboxIndication": {
            "location": "import",
            "path": "./checkbox-input.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "control's the checkbox input state"
      },
      "attribute": "indication",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "checkedChange",
      "name": "checkedChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [{
            "name": "deprecated",
            "text": "emitted if the checkbox input changes its value"
          }],
        "text": ""
      },
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      }
    }, {
      "method": "indicationChange",
      "name": "indicationChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "emitted if the checkbox input changes its value"
      },
      "complexType": {
        "original": "CheckboxCheckedIndication",
        "resolved": "\"checked\" | \"unchecked\"",
        "references": {
          "CheckboxCheckedIndication": {
            "location": "import",
            "path": "./checkbox-input.interface"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "indication",
      "methodName": "onStateChange"
    }]; }
}

