/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { Component, Event, h, Prop, State, Watch } from '@stencil/core';
import { format, setMonth } from 'date-fns';
import { DEFAULT_LOCALE, LOCALE_MAP } from '../../../../utils/localization';
import state from '../../../../utils/locale-store';
export class MonthHeader {
  handleMonthChange(newValue) {
    this.setFormattedMonth(newValue);
  }
  handleYearChange(newValue) {
    this.displayedYear = newValue;
  }
  componentWillLoad() {
    this.setFormattedMonth(this.month);
    this.displayedYear = this.year;
  }
  arrowClickHandler(arrowDirection) {
    this.arrowClicked.emit(arrowDirection);
  }
  handleKeyboardClick(event) {
    if ((event.key !== 'Enter' && event.key !== ' ') || event.defaultPrevented)
      return;
    event.target.click();
  }
  render() {
    return (h("div", { class: "bci-core-month-header" },
      h("div", { "data-test": "webcore.webcomponents.month-header.yearMonthSelection", class: {
          'month-header': true,
          opened: !!this.yearMonthSelectionStep,
        }, tabIndex: 0, role: "button", "aria-label": `${!!this.yearMonthSelectionStep ? 'Close' : 'Open'} the Year/Month Selection`, onKeyDown: (ev) => this.handleKeyboardClick(ev), onClick: () => {
          this.toggleShowYearMonthSelection.emit({ newState: !!this.yearMonthSelectionStep ? false : true });
        } },
        h("p", null, `${this.displayedMonth} ${this.displayedYear}` || 'Month Header'),
        h("span", { class: "open-arrow" },
          h("i", { class: "bosch-ic bosch-ic-clickable bosch-ic-down" }))),
      h("div", null,
        h("span", { class: { 'left-arrow': true, disabled: this.yearMonthSelectionStep === 'month' }, role: "button", tabIndex: 0, "aria-label": `Show previous ${!!this.yearMonthSelectionStep ? '20 years' : 'month'}`, onKeyDown: (ev) => this.handleKeyboardClick(ev), onClick: () => this.arrowClickHandler({ direction: 'prev' }) },
          h("i", { class: "bosch-ic bosch-ic-clickable bosch-ic-back-left", "data-test": "webcore.webcomponents.month-header.month-change-handler.span" })),
        h("span", { class: { 'right-arrow': true, disabled: this.yearMonthSelectionStep === 'month' }, role: "button", tabIndex: 0, "aria-label": `Show next ${!!this.yearMonthSelectionStep ? '20 years' : 'month'}`, onKeyDown: (ev) => this.handleKeyboardClick(ev), onClick: () => this.arrowClickHandler({ direction: 'next' }) },
          h("i", { "data-test": "webcore.webcomponents.bci-core-month-header-month-change-header.next", class: "bosch-ic bosch-ic-clickable bosch-ic-forward-right" })))));
  }
  setFormattedMonth(value) {
    const locale = { locale: LOCALE_MAP[state.language || DEFAULT_LOCALE.language] };
    this.displayedMonth = format(setMonth(new Date(), value), 'MMMM', locale);
  }
  static get is() { return "bci-month-header"; }
  static get originalStyleUrls() { return {
    "$": ["month-header.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["month-header.css"]
  }; }
  static get properties() { return {
    "year": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "year",
      "reflect": false
    },
    "month": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "month",
      "reflect": false
    },
    "yearMonthSelectionStep": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "year-month-selection-step",
      "reflect": false
    }
  }; }
  static get states() { return {
    "displayedMonth": {},
    "displayedYear": {}
  }; }
  static get events() { return [{
      "method": "arrowClicked",
      "name": "arrowClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "ArrowClickObject",
        "resolved": "ArrowClickObject",
        "references": {
          "ArrowClickObject": {
            "location": "import",
            "path": "../datepicker.models"
          }
        }
      }
    }, {
      "method": "toggleShowYearMonthSelection",
      "name": "toggleShowYearMonthSelection",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "{ newState: boolean }",
        "resolved": "{ newState: boolean; }",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "month",
      "methodName": "handleMonthChange"
    }, {
      "propName": "year",
      "methodName": "handleYearChange"
    }]; }
}

