/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Prop } from '@stencil/core';
import { getDate, getMonth, getYear, isAfter, isBefore, isSameDay, isWithinInterval, parse } from 'date-fns';
import { createDate } from '../../../../utils/utils';
export class Weekdays {
  singleDateSelectedHandler(input) {
    this.singleDateSelected.emit(input);
  }
  rangeDateSelectedHandler(input) {
    this.rangeDateSelected.emit(input);
  }
  render() {
    const cells = [];
    const offset = this.offset % 7;
    for (let blank = 0; blank < offset; blank++) {
      cells.push(this.emptyDateCell());
    }
    for (let day = 1; day <= this.daysInMonth; day++) {
      /** Whether the day is selected  */
      let selected;
      /** Whether the day is within the selected range */
      let selectedRange;
      /** Whether the day is the first day of the selected range */
      let selectedFirstDateRange;
      /** Whether the day is the last day of the selected range */
      let selectedLastDateRange;
      const maxDate = this.dateRestrictionObj.maximumDate;
      const minDate = this.dateRestrictionObj.minimumDate;
      const currentDate = this.timeZone === undefined
        ? createDate(new Date(), this.year, this.month, day)
        : createDate(new Date(new Date().toLocaleString('en-US', { timeZone: this.timeZone })), this.year, this.month, day);
      const todaysDate = isSameDay(currentDate, parse(this.todaysDate, this.formatDate, new Date()));
      // disabled cells
      if ((!isSameDay(minDate, currentDate) && isAfter(minDate, currentDate)) ||
        (!isSameDay(maxDate, currentDate) && isBefore(maxDate, currentDate))) {
        cells.push(h("td", { class: {
            'bci-core-disabled': true,
            'bci-core-today': todaysDate,
          } },
          h("div", { class: "bci-core-date" }, day)));
        continue;
      }
      // clickable cells
      if (this.datesObj.startDate && this.datesObj.endDate) {
        // if startDate and endDate are selected
        const startDate = parse(this.datesObj.startDate, this.formatDate, new Date());
        const endDate = parse(this.datesObj.endDate, this.formatDate, new Date());
        if (isAfter(endDate, startDate) && isWithinInterval(currentDate, { start: startDate, end: endDate })) {
          selected = true;
          selectedRange = true;
        }
        else {
          selected = false;
        }
        if (isSameDay(currentDate, startDate)) {
          selectedFirstDateRange = true;
          selected = true;
        }
        if (isSameDay(currentDate, endDate)) {
          selectedLastDateRange = true;
          selected = true;
          selectedRange = true;
        }
        if (isSameDay(currentDate, startDate) && isSameDay(startDate, endDate)) {
          selected = true;
          selectedFirstDateRange = false;
          selectedLastDateRange = false;
          selectedRange = false;
        }
      }
      else {
        // single date picker
        if (this.datesObj.startDate || this.selectedDate) {
          const selectedDate = parse(this.datesObj.startDate || this.selectedDate, this.formatDate, new Date());
          selected = getDate(selectedDate) === day && getMonth(selectedDate) === this.month && getYear(selectedDate) === this.year;
        }
      }
      const classes = {
        'bci-core-week-days': true,
        'bci-core-selected': selected,
        'bci-core-range': selectedRange,
        'bci-core-first-date-range': selectedFirstDateRange,
        'bci-core-last-date-range': selectedLastDateRange,
        'bci-core-today': selected ? false : todaysDate,
        'bci-core-last-week-day': (cells.length + 1) % 7 === 0,
      };
      cells.push(h("td", { "data-test": "webcore.webcomponents.weekdays.bci-weekdays.selected-day", class: classes, onClick: () => this.rangeDate ? this.rangeDateSelectedHandler({ selectedDay: day }) : this.singleDateSelectedHandler({ selectedDay: day }) },
        h("div", { class: "bci-core-date" }, day)));
    }
    while (cells.length % 7 !== 0) {
      cells.push(this.emptyDateCell());
    }
    const table = cells.reduce((acc, curr, index) => {
      const weekNumber = Math.floor(index / 7);
      acc[weekNumber].push(curr);
      return acc;
    }, [[], [], [], [], [], []]);
    return (h("table", { class: "bci-core-weekdays-table" },
      h("tbody", { class: "bci-core-week-days-container" }, table.sort().map((row, index) => (h("tr", { key: index }, row.map((cell) => cell)))))));
  }
  emptyDateCell() {
    return (h("td", { class: "bci-core-empty" },
      h("div", { class: "bci-core-date" })));
  }
  static get is() { return "bci-weekdays"; }
  static get originalStyleUrls() { return {
    "$": ["weekdays.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["weekdays.css"]
  }; }
  static get properties() { return {
    "datesObj": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "DatesObject",
        "resolved": "DatesObject",
        "references": {
          "DatesObject": {
            "location": "import",
            "path": "../datepicker.models"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "daysInMonth": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "days-in-month",
      "reflect": false
    },
    "lastDayOfMonth": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Date",
        "resolved": "Date",
        "references": {
          "Date": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "month": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "month",
      "reflect": false
    },
    "rangeDate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "range-date",
      "reflect": false
    },
    "dateRestrictionObj": {
      "type": "any",
      "mutable": false,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "date-restriction-obj",
      "reflect": false
    },
    "offset": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "offset",
      "reflect": false
    },
    "selectedDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "selected-date",
      "reflect": false
    },
    "year": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "year",
      "reflect": false
    },
    "todaysDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "todays-date",
      "reflect": false
    },
    "formatDate": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "format-date",
      "reflect": false
    },
    "timeZone": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "time-zone",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "singleDateSelected",
      "name": "singleDateSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event emitted for a single date selection. Listened to in dialog.tsx"
      },
      "complexType": {
        "original": "DaySelectedObject",
        "resolved": "DaySelectedObject",
        "references": {
          "DaySelectedObject": {
            "location": "import",
            "path": "../datepicker.models"
          }
        }
      }
    }, {
      "method": "rangeDateSelected",
      "name": "rangeDateSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event emitted for a range date selection. Listened to in dialog.tsx"
      },
      "complexType": {
        "original": "DaySelectedObject",
        "resolved": "DaySelectedObject",
        "references": {
          "DaySelectedObject": {
            "location": "import",
            "path": "../datepicker.models"
          }
        }
      }
    }]; }
}

