/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { Component, Host, h, Event, Prop, State, Method } from '@stencil/core';
import { translate } from '../../../utils/utils';
export class TemplateList {
  constructor() {
    /**
     * Whether the templatesList should be visible.
     * Using this prop instead of traditional conditional rendering to preserve the state within this component.
     */
    this.visible = false;
  }
  /**
   * Clears internal timer and resets selected template
   */
  async reset() {
    this.selectedTemplateId = '';
    this.clearTimer();
  }
  clearTimer() {
    if (this.timerId) {
      clearInterval(this.timerId);
      this.timerId = 0;
    }
  }
  updateTemplate(event, option) {
    event.stopPropagation();
    this.selectedTemplateId = option.id;
    this.clearTimer();
    this.applyTemplate(option, true);
    if (option.liveUpdates && option.refreshInterval && option.refreshInterval > 0) {
      this.timerId = window.setInterval(() => {
        this.applyTemplate(option, false);
      }, option.refreshInterval);
    }
  }
  applyTemplate(option, firstEmit) {
    this.templateUpdate.emit({ timeStamp: option.calculateTemplate(), firstEmit, id: this.selectedTemplateId });
  }
  render() {
    var _a;
    return this.visible ? (h(Host, { class: "templates-container" },
      h("ul", { class: "mdc-list", role: "listbox" }, (_a = this.templatesList) === null || _a === void 0 ? void 0 : _a.map((element) => 'id' in element ? (h("li", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.selecttemplate", class: {
          'mdc-list-item': true,
          selected: this.selectedTemplateId === element.id,
          disabled: element.disabled,
        }, role: "option", "aria-label": `Select ${element.label}`, title: element.label, onClick: (item) => this.updateTemplate(item, element) },
        h("label", { class: "mdc-list-item__text" }, element.label))) : (
      // element is TemplateGroup
      element.templates.length > 0 && (h("div", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.optiongroup" },
        h("span", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.optiongrouplabel", class: { 'optiongroup-label': true, disabled: element.disabled } }, element.label),
        element.templates.map((template) => (h("li", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.selecttemplate", class: {
            'mdc-list-item': true,
            selected: this.selectedTemplateId === template.id,
            disabled: template.disabled || element.disabled,
          }, role: "option", "aria-label": `Select ${template.label}`, title: template.label, onClick: (item) => this.updateTemplate(item, template) },
          h("label", { class: "mdc-list-item__text" }, template.label))))))))),
      h("div", { class: "bci-core-datepicker-selection" },
        h("button", { "data-test": "webcore.webcomponents.datetime-picker.core-datetime-picker.timerange", class: "button-secondary no-arrow", onClick: () => this.showTimeRanges.emit() }, translate('calendar'))))) : null;
  }
  static get is() { return "bci-template"; }
  static get originalStyleUrls() { return {
    "$": ["template.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["template.css"]
  }; }
  static get properties() { return {
    "templatesList": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Array<Template | TemplateGroup>",
        "resolved": "(Template | TemplateGroup)[]",
        "references": {
          "Array": {
            "location": "global"
          },
          "Template": {
            "location": "import",
            "path": "../datetime-picker.interface"
          },
          "TemplateGroup": {
            "location": "import",
            "path": "../datetime-picker.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Which time frames should be displayed"
      }
    },
    "visible": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the templatesList should be visible.\nUsing this prop instead of traditional conditional rendering to preserve the state within this component."
      },
      "attribute": "visible",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "selectedTemplateId": {}
  }; }
  static get events() { return [{
      "method": "showTimeRanges",
      "name": "showTimeRanges",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits if the user clicks on the time range button"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "templateUpdate",
      "name": "templateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits whenever the value of a time frame changes"
      },
      "complexType": {
        "original": "TemplateEvent",
        "resolved": "TemplateEvent",
        "references": {
          "TemplateEvent": {
            "location": "import",
            "path": "../model"
          }
        }
      }
    }]; }
  static get methods() { return {
    "reset": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Clears internal timer and resets selected template",
        "tags": []
      }
    }
  }; }
}

