/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/**
 * Copyright (C) 2020. Robert Bosch GmbH Copyright (C) 2020. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, h, Prop, Element, Event, Host, Method } from '@stencil/core';
export class ColumnList {
  constructor() {
    this.list = [];
    this.ColumnListElement = ({ listItem, index, id }, children) => (h("li", { class: `mdc-list-item ${this.selectedId === id ? 'selected' : ''}`, id: `li-${id}`, role: "checkbox", "aria-checked": "false", tabindex: index, onClick: () => this.handleColumnItemSelection(listItem) },
      h("span", { class: "mdc-list-item__graphic" }, children),
      h("label", { class: "mdc-list-item__text" }, listItem.name),
      listItem.hasChildren ? h("span", { class: "bosch-ic bosch-ic-forward-right bosch-ic-clickable" }) : ''));
  }
  componentDidRender() {
    this.markCheckedItems();
  }
  async markCheckedItems() {
    if (!this.list) {
      return;
    }
    this.list.forEach((item) => {
      const checkbox = this.el.querySelector('#checkbox-item-' + item.id);
      if (!checkbox) {
        return;
      }
      if (this.facilitySelectorController.selectionState.isChecked(item)) {
        checkbox.checked = true;
      }
      else if (this.facilitySelectorController.selectionState.isIndeterminate(item)) {
        checkbox.indeterminate = true;
      }
      else {
        checkbox.checked = false;
        checkbox.indeterminate = false;
      }
    });
  }
  handleColumnItemSelection(listItem) {
    const id = listItem.id;
    this.selectedId === id ? (this.selectedId = null) : (this.selectedId = id);
    this.columnItemSelected.emit({
      item: listItem,
      isSelectedOrChecked: this.selectedId !== null,
    });
  }
  handleColumnItemChecked(event, listItem) {
    event.stopPropagation();
    this.columnItemChecked.emit({
      item: listItem,
      isSelectedOrChecked: event.detail,
    });
  }
  render() {
    return (h(Host, { class: "column-list-container" },
      h("ul", { "data-test": "webcore.webcomponents.column-list.list-item", class: "mdc-list", role: "listbox", "aria-label": "List with checkbox items" }, this.list.map((listItem, index) => (h(this.ColumnListElement, { listItem: listItem, index: index, id: listItem.id },
        h("checkbox-input", { "data-test": "webcore.webcomponents.column-list.bci.column-checkbox-input", checkboxId: 'checkbox-item-' + listItem.id, onCheckedChange: (checked) => this.handleColumnItemChecked(checked, listItem) })))))));
  }
  static get is() { return "bci-column-list"; }
  static get originalStyleUrls() { return {
    "$": ["column-list.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["column-list.css"]
  }; }
  static get properties() { return {
    "list": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Facility[]",
        "resolved": "Facility[]",
        "references": {
          "Facility": {
            "location": "import",
            "path": "../facility.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "[]"
    },
    "selectedId": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "selected-id",
      "reflect": false
    },
    "facilitySelectorController": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "FacilitySelectorController",
        "resolved": "FacilitySelectorController",
        "references": {
          "FacilitySelectorController": {
            "location": "import",
            "path": "../../.."
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    }
  }; }
  static get events() { return [{
      "method": "columnItemSelected",
      "name": "columnItemSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "ColumnItemSelectedOrChecked",
        "resolved": "ColumnItemSelectedOrChecked",
        "references": {
          "ColumnItemSelectedOrChecked": {
            "location": "import",
            "path": "../facility.interface"
          }
        }
      }
    }, {
      "method": "columnItemChecked",
      "name": "columnItemChecked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "ColumnItemSelectedOrChecked",
        "resolved": "ColumnItemSelectedOrChecked",
        "references": {
          "ColumnItemSelectedOrChecked": {
            "location": "import",
            "path": "../facility.interface"
          }
        }
      }
    }]; }
  static get methods() { return {
    "markCheckedItems": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          },
          "HTMLInputElement": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "el"; }
}

