/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2020 Robert Bosch GmbH Copyright (C) 2020 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Host, h, Prop, State, Event } from '@stencil/core';
import { translate } from '../../../utils/utils';
export class RecentSearch {
  constructor() {
    this.expanded = true;
    this.recentSearches = [];
  }
  toggleRecentSearchesDisplay() {
    this.expanded = !this.expanded;
  }
  async componentWillLoad() {
    await this.setRecentSearches();
  }
  async setRecentSearches() {
    if (!this.recentSearchController) {
      return;
    }
    if (this.recentSearchController.recentSearches) {
      this.recentSearches = [...this.recentSearchController.recentSearches];
    }
    else {
      try {
        await this.recentSearchController.setRecentSearches();
        this.recentSearches = [...this.recentSearchController.recentSearches];
      }
      catch (_a) {
        this.recentSearches = [];
      }
    }
  }
  selectRecentSearch(recentSearch) {
    this.recentSearchSelected.emit(recentSearch);
  }
  render() {
    return (h(Host, { class: "recent-search-container" },
      h("div", { class: "recent-search-title", onClick: () => this.toggleRecentSearchesDisplay(), "data-test": "webcore.webcomponents.recent-search.toggle.div" },
        translate('recentSearch'),
        h("span", { class: `bosch-ic ${!!this.expanded ? 'bosch-ic-up' : 'bosch-ic-down'}` })),
      !!this.expanded && this.renderList()));
  }
  renderList() {
    return this.recentSearches.map((result) => (h("div", { "data-test": "webcore.webcomponents.recent-search.bci.facility-search.select-recent-search", class: "recent-search-breadcrumb", onClick: () => this.selectRecentSearch(result) }, result.checkedItemsByLevel.map((entry, index) => entry && (h("div", { class: "recent-search-breadcrumb-piece" },
      index !== 0 && h("span", { class: "bosch-ic bosch-ic-small bosch-ic-forward-right" }),
      entry.length > 0 ? entry.map((res) => res.name).join(', ') : '...'))))));
  }
  static get is() { return "bci-facility-recent-search"; }
  static get originalStyleUrls() { return {
    "$": ["recent-search.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["recent-search.css"]
  }; }
  static get properties() { return {
    "expanded": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "expanded",
      "reflect": false,
      "defaultValue": "true"
    },
    "recentSearchController": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "RecentSearchController",
        "resolved": "RecentSearchController",
        "references": {
          "RecentSearchController": {
            "location": "import",
            "path": "../../.."
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    }
  }; }
  static get states() { return {
    "recentSearches": {}
  }; }
  static get events() { return [{
      "method": "recentSearchSelected",
      "name": "recentSearchSelected",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "RecentSearchItem",
        "resolved": "RecentSearchItem",
        "references": {
          "RecentSearchItem": {
            "location": "import",
            "path": "../facility.interface"
          }
        }
      }
    }]; }
}

