/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Prop, h, State, Listen, Element } from '@stencil/core';
import { translate } from '../../utils/utils';
import { setLocale } from '../../utils/locale-store';
export class FooterComponent {
  constructor() {
    this.hideFooterText = 'hideFooter';
    this.showFooterText = 'showFooter';
    this.showFooterToggle = true;
    this.collapseFooter = false;
    this.isComponentLoaded = false;
  }
  async componentWillLoad() {
    await setLocale();
  }
  componentDidLoad() {
    this.isComponentLoaded = true;
    if (this.alwaysSlotExpanded && this.alwaysSlotCollapsed) {
      this.alwaysVisibleSlotContent = this.alwaysSlotExpanded.innerHTML || this.alwaysSlotCollapsed.innerHTML;
    }
    this.handleResize();
  }
  handleResize() {
    const currentWidth = this.el.offsetWidth;
    if (!this.isComponentLoaded) {
      return;
    }
    // to stay always in collapsed mode in vp1/vp2
    if (currentWidth < 769 && !this.collapseFooter) {
      this.showCollapsedFooter();
      return;
    }
    if ((this.collapseFooter && currentWidth < this.footerWidth) || (!this.collapseFooter && currentWidth > this.footerWidth)) {
      return;
    }
    if (currentWidth < 769) {
      this.showCollapsedFooter();
      return;
    }
    // Resetting to default
    this.showExpandedFooter();
    clearTimeout(this.resizeTimeout);
    this.resizeTimeout = setTimeout(() => {
      this.resizeFooter();
      this.footerWidth = currentWidth;
    }, 100);
  }
  resizeFooter() {
    const basePanelElement = this.el.shadowRoot.querySelector('.bci-portal-footer-links-panel');
    if (basePanelElement && basePanelElement.clientWidth === 0) {
      this.handleResize();
    }
    if (basePanelElement.scrollWidth > basePanelElement.clientWidth) {
      this.showCollapsedFooter();
    }
    else {
      this.showExpandedFooter();
    }
  }
  showCollapsedFooter() {
    this.showFooterToggle = false;
    this.collapseFooter = true;
    this.alwaysSlotExpanded.innerHTML = '';
    this.alwaysSlotCollapsed.innerHTML = this.alwaysVisibleSlotContent;
  }
  showExpandedFooter() {
    this.collapseFooter = false;
    this.showFooterToggle = true;
    this.alwaysSlotExpanded.innerHTML = this.alwaysVisibleSlotContent;
    this.alwaysSlotCollapsed.innerHTML = '';
  }
  render() {
    return (h("footer", { class: "bci-portal-footer" },
      h("div", { "data-test": "webcore.webcomponents.footer-component.bci-portal-footer.footer-link", class: `bci-portal-footer-links-panel ${this.showFooterToggle ? 'show' : 'hide'}
                    ${!this.collapseFooter ? 'expanded' : ''}` },
        h("div", { class: "bci-portal-footer-copyright" }, !this.copyrightLabel || this.copyrightLabel === '' ? '' : h("span", null,
          "\u00A9 ",
          this.copyrightLabel)),
        h("div", { class: `bci-portal-footer-links ${!this.collapseFooter ? 'expanded' : ''}` },
          h("span", { ref: (el) => (this.alwaysSlotExpanded = el) },
            h("slot", { name: "alwaysVisible" })),
          h("slot", null))),
      h("div", { class: `bci-portal-footer-base-panel ${this.collapseFooter ? 'show' : 'hide'}` },
        h("span", { ref: (el) => (this.alwaysSlotCollapsed = el) }),
        h("div", { class: "bci-portal-footer-toggle-wrapper" },
          h("div", { "data-test": "webcore.webcomponents.footer-component.bci-portal-footer.base-panel.footer-toggle", class: "bci-portal-footer-toggle bosch-ic-clickable", onClick: () => (this.showFooterToggle = !this.showFooterToggle) },
            h("span", { class: "bci-portal-footer-toggle-text" }, this.showFooterToggle ? translate(this.hideFooterText) : translate(this.showFooterText)),
            h("span", { class: `bosch-ic bosch-ic-medium ${this.showFooterToggle ? 'bosch-ic-down' : 'bosch-ic-up'}` }))))));
  }
  static get is() { return "bci-portal-footer"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["footer.component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["footer.component.css"]
  }; }
  static get properties() { return {
    "copyrightLabel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Copyright text"
      },
      "attribute": "copyright-label",
      "reflect": false
    }
  }; }
  static get states() { return {
    "showFooterToggle": {},
    "collapseFooter": {}
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "resize",
      "method": "handleResize",
      "target": "window",
      "capture": false,
      "passive": true
    }]; }
}

