/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { MDCDialog } from '@material/dialog';
import { MDCMenu } from '@material/menu/component';
import { DefaultFocusState } from '@material/menu/constants';
import { Component, Element, h, Listen, State, Prop } from '@stencil/core';
import { MessagesController } from '../../utils/messages-controller';
import { formatDateAsDayString, translate } from '../../utils/utils';
import { NotificationClass } from './header-message-icon.interface';
import { setLocale } from '../../utils/locale-store';
export class HeaderMessageIconComponent {
  constructor() {
    this.isMenuOpen = false;
    this.controller = new MessagesController();
    this.previousMessage = {};
  }
  async componentWillLoad() {
    await setLocale();
    this.loadMessages();
  }
  componentDidRender() {
    this.menu = new MDCMenu(this.el.shadowRoot.querySelector('.bci-portal-message-history-menu'));
    this.menu.setAnchorMargin({ top: 62, right: -7, left: 150 });
    this.menu.setDefaultFocusState(DefaultFocusState.NONE);
    this.dialog = new MDCDialog(window.document.querySelector('bci-portal-messages').shadowRoot.querySelector('.mdc-dialog'));
  }
  onMessageCreated(event) {
    this.messages.splice(0, 0, event.detail);
    this.controller.updateMessages(this.messages, this.localStorageKey);
  }
  loadMessages() {
    this.messages = this.controller.getMessages(this.localStorageKey);
  }
  updateMessage(message, updates) {
    const toBeUpdated = this.messages.find((msg) => JSON.stringify(msg) === JSON.stringify(message));
    if (toBeUpdated) {
      Object.assign(toBeUpdated, updates);
    }
    this.messages = [...this.messages];
  }
  toggleMenu() {
    if (window.innerWidth < 768) {
      this.openDialog();
      return;
    }
    this.menu.open = !this.menu.open;
    // Workaround for 'greedy' body click handler bug in MDCMenu
    // https://github.com/material-components/material-components-web/issues/6188
    const messageIconElement = this.el.shadowRoot.querySelector('bci-portal-badge').querySelector('.bci-portal-badge');
    const counterElement = this.el.shadowRoot.querySelector('span.bosch-ic-notification');
    const elements = [messageIconElement, counterElement];
    document.body.addEventListener('click', (e) => {
      elements.forEach((element) => {
        if (element === e.composedPath()[0]) {
          e.stopPropagation();
        }
      });
    }, { capture: true, once: true });
  }
  openDialog() {
    window.document.querySelector('body').classList.add('mdc-dialog-blur');
    this.isMenuOpen = false;
    this.menu.open = false;
    this.dialog.open();
  }
  //added this method to close the pop up on click
  closeMenuPopUp() {
    this.isMenuOpen = false;
    this.menu.open = false;
  }
  renderMessageHistoryMenu() {
    return (h("div", { class: `mdc-menu mdc-menu-surface bci-portal-message-history-menu ${this.messages.length === 0 ? 'bci-portal-message-history-menu-empty' : ''}` }, this.messages.length === 0 ? (h("div", { class: "bci-portal-message-history-empty-message" }, translate('emptyMessageList'))) : (h("span", null,
      this.messages.slice(0, 5).map((message, index, messages) => (h("span", null,
        (index === 0 ||
          formatDateAsDayString(message.timeStamp, this.dateFormat) !==
            formatDateAsDayString(messages[index - 1].timeStamp, this.dateFormat)) && (h("div", { class: "bci-portal-message-history-spacer" }, formatDateAsDayString(message.timeStamp, this.dateFormat))),
        h("div", { "data-test": "webcore.webcomponents.header-message-icon.component.bci-portal-message-history.open-dialog", class: `bci-portal-message-history-entry ${this.controller.determineClassColor(message)}`, onClick: () => this.openDialog() },
          h("span", { class: this.controller.determineClassIcon(message) }),
          h("div", { class: "bci-portal-message-history-entry-flex-container" },
            h("span", null, message.title)))))),
      h("div", { class: "bci-portal-message-history-menu-footer" },
        h("button", { "data-test": "webcore.webcomponents.header-message-icon.open-dialog.button", onClick: () => this.openDialog(), class: "button-integrated" }, translate('seeAllMessages')))))));
  }
  render() {
    return (h("div", { class: "bci-portal-header-message-icon mdc-menu-surface--anchor" },
      h("span", { class: "bosch-ic bosch-ic-medium bosch-ic-clickable bosch-ic-notification", "data-test": "webcore.webcomponents.header-message-icon.menu.span", onClick: () => this.toggleMenu() }, this.text || ''),
      h("bci-portal-badge", { "data-test": "webcore.webcomponents.header-message-icon.component.bci-portal-header-message-icon.portal-badge", value: this.messages.length > 99 ? '99+' : this.messages.length, redBackground: this.messages.some((msg) => !msg.isRead && msg.class === NotificationClass.Error), onClick: () => this.toggleMenu() }),
      this.renderMessageHistoryMenu()));
  }
  static get is() { return "bci-portal-header-message-icon"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["header-message-icon.component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["header-message-icon.component.css"]
  }; }
  static get properties() { return {
    "dateFormat": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "date-format",
      "reflect": false
    },
    "localStorageKey": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "local-storage-key",
      "reflect": false
    },
    "text": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "text",
      "reflect": false
    }
  }; }
  static get states() { return {
    "messages": {}
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "bci.portal.message.created",
      "method": "onMessageCreated",
      "target": "window",
      "capture": false,
      "passive": false
    }, {
      "name": "bci.portal.message.updated",
      "method": "loadMessages",
      "target": "window",
      "capture": false,
      "passive": false
    }, {
      "name": "bci.portal.message.close",
      "method": "closeMenuPopUp",
      "target": "window",
      "capture": false,
      "passive": false
    }]; }
}

