/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Prop, h, Listen, Event, State, Watch } from '@stencil/core';
import { NavigationController } from '../../utils/navigation-controller';
/**
 * @deprecated
 *
 * Please use the bci-header
 */
export class HeaderComponent {
  constructor() {
    this.navigationItems = [];
    this.maximized = 'None';
    this.showMaximizedBurgerMenuIcon = false;
    this.showSettingsIcon = false;
    this.pieces = [];
    this.maximizedStyle = '';
  }
  handleClickNavItemEvent() {
    const navigationController = new NavigationController();
    const path = `${window.location.pathname}${window.location.hash || '#'}`;
    const navItem = navigationController.getSelectedNavigationItem(path, this.navigationItems || []);
    if (navItem) {
      this.headerTitle = navItem.title;
      this.showSettingsIcon = navItem.showSettingsIcon;
    }
    this.pieces = navigationController.getTranslatedPath(path, this.navigationItems || []);
    this.navigationItems = [...this.navigationItems];
  }
  handleClickHeaderItemEvent(event) {
    const path = event.detail;
    if (!path || path.length == 0) {
      // Do not navigate, when there is no path (e.g. fullscreen header button)
      return;
    }
    const navItem = new NavigationController().setActiveNavigationByPath(path, this.navigationItems);
    if (navItem) {
      this.navigationItemClicked.emit(navItem);
    }
  }
  setHeaderStyleClass() {
    if (this.maximized === 'Maximized') {
      this.maximizedStyle = ' maximized';
      return;
    }
    if (this.maximized === 'MaximizedMenuOpen') {
      this.maximizedStyle = ' maximized maximized-menu-open';
      return;
    }
    this.maximizedStyle = '';
  }
  renderMaximizedMenuBurgerIcon() {
    if (this.showMaximizedBurgerMenuIcon) {
      return h("bci-portal-header-maximized-burger-icon", null);
    }
  }
  clickSettingsIcon() {
    this.settingsIconClicked.emit();
  }
  render() {
    return (h("header", { class: 'bci-portal-header' + this.maximizedStyle },
      h("div", { class: "bci-portal-header-top-row" },
        this.renderMaximizedMenuBurgerIcon(),
        h("span", { class: 'bci-portal-header-title' + this.maximizedStyle }, this.headerTitle),
        this.showSettingsIcon && !document.currentScript ? (h("span", { onClick: () => this.clickSettingsIcon(), "data-test": "webcore.webcomponents.header.settings.span", id: "header-settings-icon", class: "bci-portal-header-settings-icon\n                                    bosch-ic\n                                    bosch-ic-medium\n                                    bosch-ic-clickable\n                                    bosch-ic-settings" })) : ('')),
      h("div", { class: 'bci-portal-header-toolbar' + this.maximizedStyle },
        h("ul", { class: "bci-portal-header-menu" },
          h("slot", null)))));
  }
  static get is() { return "bci-portal-header"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["header.component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["header.component.css"]
  }; }
  static get properties() { return {
    "navigationItems": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "SidebarNavItem[]",
        "resolved": "SidebarNavItem[]",
        "references": {
          "SidebarNavItem": {
            "location": "import",
            "path": "../../interfaces/navigation.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "[]"
    },
    "maximized": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "MaximizedMode",
        "resolved": "\"Maximized\" | \"MaximizedMenuOpen\" | \"None\"",
        "references": {
          "MaximizedMode": {
            "location": "import",
            "path": "../../interfaces/utils.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "maximized",
      "reflect": false,
      "defaultValue": "'None'"
    },
    "showMaximizedBurgerMenuIcon": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "show-maximized-burger-menu-icon",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get states() { return {
    "showSettingsIcon": {},
    "pieces": {},
    "headerTitle": {},
    "maximizedStyle": {}
  }; }
  static get events() { return [{
      "method": "settingsIconClicked",
      "name": "bci.portal.header.settingsIconClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      }
    }, {
      "method": "navigationItemClicked",
      "name": "bci.portal.navigation.itemClicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "SidebarNavItem",
        "resolved": "SidebarNavItem",
        "references": {
          "SidebarNavItem": {
            "location": "import",
            "path": "../../interfaces/navigation.interface"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "maximized",
      "methodName": "setHeaderStyleClass"
    }, {
      "propName": "showMaximizedBurgerMenuIcon",
      "methodName": "renderMaximizedMenuBurgerIcon"
    }]; }
  static get listeners() { return [{
      "name": "bci.portal.navigation.itemClicked",
      "method": "handleClickNavItemEvent",
      "target": "window",
      "capture": false,
      "passive": false
    }, {
      "name": "bci.portal.changedUrl",
      "method": "handleClickNavItemEvent",
      "target": "window",
      "capture": false,
      "passive": false
    }, {
      "name": "bci.portal.header.navItemClicked",
      "method": "handleClickHeaderItemEvent",
      "target": "window",
      "capture": false,
      "passive": false
    }]; }
}

