/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2023 Robert Bosch GmbH Copyright (C) 2023 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { MDCDialog } from '@material/dialog';
import { Component, h, Method, Element, Prop, Watch } from '@stencil/core';
export class ModalDialog {
  constructor() {
    this.defaultWidth = '90%';
    this.defaultHeight = '90%';
    this.containerStyles = {
      width: this.defaultWidth,
    };
    this.surfaceStyles = {
      height: this.defaultHeight,
    };
  }
  onConfigChange(config) {
    var _a, _b;
    this.containerStyles = {
      width: (_a = config.width) !== null && _a !== void 0 ? _a : this.defaultWidth,
      minWidth: config.minWidth,
      maxWidth: config.maxWidth,
    };
    this.surfaceStyles = {
      height: (_b = config.height) !== null && _b !== void 0 ? _b : this.defaultHeight,
      minHeight: config.minHeight,
      maxHeight: config.maxHeight,
    };
  }
  /** Opens the modal dialog. */
  async open() {
    return new Promise((resolve) => {
      if (this.dialog) {
        return;
      }
      this.dialog = new MDCDialog(this.hostElement.shadowRoot.querySelector('.mdc-dialog'));
      this.dialog.scrimClickAction = '';
      this.dialog.escapeKeyAction = '';
      this.dialog.listen('MDCDialog:closed', () => {
        window.document.querySelector('body').classList.remove('mdc-dialog-blur');
        this.dialog = null;
        resolve();
      });
      window.document.querySelector('body').classList.add('mdc-dialog-blur');
      this.dialog.open();
    });
  }
  /** Closes the modal dialog. */
  async close() {
    return new Promise((resolve, reject) => {
      if (this.dialog && this.dialog.isOpen) {
        this.dialog.close();
        this.dialog.listen('MDCDialog:closed', () => {
          resolve();
        });
      }
      else {
        reject();
      }
    });
  }
  render() {
    return (h("div", { class: "mdc-dialog mdc-dialog--sheet mdc-dialog--no-content-padding" },
      h("div", { class: "mdc-dialog__container", style: this.containerStyles },
        h("div", { class: "mdc-dialog__surface", style: this.surfaceStyles, role: "dialog", "aria-modal": "true", "aria-labelledby": "my-dialog-title", "aria-describedby": "my-dialog-content" },
          h("div", { class: "mdc-dialog__header" },
            h("span", { class: "mdc-dialog__title" }, this.dialogTitle),
            h("span", { class: "mdc-icon-button mdc-dialog__close bosch-ic bosch-ic-clickable bosch-ic-close", "data-mdc-dialog-action": "close", tabindex: "0" })),
          h("div", { class: "mdc-dialog__content" },
            h("slot", null)))),
      h("div", { class: "mdc-dialog__scrim" })));
  }
  static get is() { return "bci-modal-dialog"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["modal-dialog.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["modal-dialog.css"]
  }; }
  static get properties() { return {
    "dialogTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "An optional title"
      },
      "attribute": "dialog-title",
      "reflect": false
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "ModalDialogConfig",
        "resolved": "ModalDialogConfig",
        "references": {
          "ModalDialogConfig": {
            "location": "import",
            "path": "./modal-dialog.interface"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "An optional configuration"
      }
    }
  }; }
  static get methods() { return {
    "open": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Opens the modal dialog.",
        "tags": []
      }
    },
    "close": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "Closes the modal dialog.",
        "tags": []
      }
    }
  }; }
  static get elementRef() { return "hostElement"; }
  static get watchers() { return [{
      "propName": "config",
      "methodName": "onConfigChange"
    }]; }
}

