/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2021 Robert Bosch GmbH Copyright (C) 2021 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Prop, Watch, Method } from '@stencil/core';
import { translate } from '../../../utils/utils';
export class MultiSelectorInput {
  constructor() {
    /** text for the input field */
    this.searchValue = '';
    /** text for the placeholder of the input field  */
    this.searchPlaceholder = translate('Search');
  }
  onSearchValueChange(value) {
    this.searchValue = value;
  }
  /** sets the cursor/focus on the input element */
  async setFocusOnInputField() {
    this.inputElement.focus();
  }
  componentWillRender() {
    if (this.inputElement && this.readonly) {
      this.inputElement.setAttribute('readonly', '');
    }
    else if (this.inputElement) {
      this.inputElement.removeAttribute('readonly');
    }
  }
  render() {
    var _a;
    return (h("div", { class: "search-container-input" },
      h("input", { ref: (el) => (this.inputElement = el), value: this.searchValue, onFocus: () => this.focusInput.emit(), onBlur: () => this.blurInput.emit(), onInput: (event) => this.onInputHandler(event), placeholder: this.searchPlaceholder, style: { 'min-width': String(Math.max(this.searchPlaceholder.length * 1.5, 10)) + 'ch' }, "data-test": "webcore.webcomponents.multi-select.search.input" }),
      h("bci-multi-selector-search-filter", { searchTypes: this.dataSources, defaultSearchType: this.selectedDataSource, onSelectSearchType: (event) => this.selectSearchType.emit(event.detail), onClickDisabledSearchType: () => {
          this.focusInput.emit();
        } }),
      !!this.selections && !!this.selections.length ? (h("bci-multi-selector-search-label", { onClick: () => this.focusInput.emit(), selections: this.selections })) : (''),
      h("label", { onClick: () => this.focusInput.emit(), slot: "label", class: "label-top" }, (_a = this.selectedDataSource) === null || _a === void 0 ? void 0 : _a.label),
      this.searchValue !== '' ? (h("button", { class: "button-link no-arrow", onClick: () => this.clearSearch.emit() },
        h("bci-icon", { clickable: true, name: "close" }))) : ('')));
  }
  onInputHandler(ev) {
    this.searchChange.emit(ev.target.value);
    ev.stopPropagation();
  }
  static get is() { return "bci-multi-selector-input"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["multi-selector-input.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["multi-selector-input.css"]
  }; }
  static get properties() { return {
    "searchValue": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "text for the input field"
      },
      "attribute": "search-value",
      "reflect": false,
      "defaultValue": "''"
    },
    "searchPlaceholder": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "text for the placeholder of the input field"
      },
      "attribute": "search-placeholder",
      "reflect": false,
      "defaultValue": "translate('Search')"
    },
    "dataSources": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "RootNode[]",
        "resolved": "RootNode[]",
        "references": {
          "RootNode": {
            "location": "import",
            "path": "../model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The available data sources."
      }
    },
    "selectedDataSource": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "RootNode",
        "resolved": "RootNode",
        "references": {
          "RootNode": {
            "location": "import",
            "path": "../model"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "The currently selected data source."
      }
    },
    "selections": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "NodePath[]",
        "resolved": "NodePath[]",
        "references": {
          "NodePath": {
            "location": "import",
            "path": "../model"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The current selections."
      }
    },
    "readonly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "turning the input field into an readonly modus"
      },
      "attribute": "readonly",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "searchChange",
      "name": "searchChange",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "called every time the"
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }, {
      "method": "focusInput",
      "name": "focusInput",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "emitted when the input is focused"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "blurInput",
      "name": "blurInput",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "emitted when the input onBlur is emitted"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "clearSearch",
      "name": "clearSearch",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "emitted when the input should be cleared"
      },
      "complexType": {
        "original": "void",
        "resolved": "void",
        "references": {}
      }
    }, {
      "method": "selectSearchType",
      "name": "selectSearchType",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "emits on search type selection a new rootNode the multi-selector displays the tree for"
      },
      "complexType": {
        "original": "RootNode",
        "resolved": "RootNode",
        "references": {
          "RootNode": {
            "location": "import",
            "path": "../model"
          }
        }
      }
    }]; }
  static get methods() { return {
    "setFocusOnInputField": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "sets the cursor/focus on the input element",
        "tags": []
      }
    }
  }; }
  static get watchers() { return [{
      "propName": "searchValue",
      "methodName": "onSearchValueChange"
    }]; }
}

