/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2021 Robert Bosch GmbH Copyright (C) 2021 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, Event, h, Host, Prop } from '@stencil/core';
export class MultiSelectorLevelSection {
  constructor() {
    this._nodeComparator = (a, b) => a.label.localeCompare(b.label);
    this.ColumnListElement = ({ item, index }) => (h("li", { class: `mdc-list-item 
        ${item.active ? 'active' : ''} 
        ${item.focused ? 'focused' : ''}
        ${!item.hasChildren ? 'mdc-list-item--non-interactive' : ''}
        `, role: "option", "aria-checked": "false", tabindex: index, onClick: () => this.toggleActiveChange(item) },
      h("span", { class: "mdc-list-item__graphic" },
        h("checkbox-input", { indication: item.selectionState, "data-test": "webcore.webcomponents.multi-selector.level.section.item.checkbox", onIndicationChange: (event) => this.onIndicationChange(item, event.detail) })),
      h("label", { class: "mdc-list-item__text" }, this.highLightLabel(item.label)),
      item.hasChildren ? h("bci-icon", { name: "forward-right", clickable: true }) : ''));
  }
  render() {
    var _a, _b, _c, _d, _e;
    return (h(Host, null,
      !!((_a = this.section) === null || _a === void 0 ? void 0 : _a.label) && ((_c = (_b = this.section) === null || _b === void 0 ? void 0 : _b.items) === null || _c === void 0 ? void 0 : _c.length) > 0 ? h("h1", null, this.section.label) : '',
      h("ul", { "data-test": "webcore.webcomponents.multi-selector.level.section.item", class: "mdc-list", role: "listbox", "aria-label": "List with checkbox items" }, (_e = (_d = this.section) === null || _d === void 0 ? void 0 : _d.items) === null || _e === void 0 ? void 0 : _e.sort(this._nodeComparator).map((item, index) => (h(this.ColumnListElement, { item: item, index: index }))))));
  }
  onIndicationChange(item, state) {
    this.nodeSelectionChanged.emit({ path: item.path, newState: state });
  }
  highLightLabel(label) {
    if (!this.highlight) {
      return label;
    }
    const indexSearch = label.toLowerCase().indexOf(this.highlight);
    const highlight = label.substring(indexSearch, indexSearch + this.highlight.length);
    if (indexSearch === -1) {
      return label;
    }
    return [label.substring(0, indexSearch), h("strong", null, highlight), label.substring(indexSearch + this.highlight.length)];
  }
  toggleActiveChange(item) {
    if (item.hasChildren) {
      this.nodeActiveChanged.emit({ path: item.path, active: !item.active });
    }
  }
  static get is() { return "bci-multi-selector-level-section"; }
  static get originalStyleUrls() { return {
    "$": ["multi-selector-level-section.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["multi-selector-level-section.css"]
  }; }
  static get properties() { return {
    "section": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "LevelSection",
        "resolved": "LevelSection",
        "references": {
          "LevelSection": {
            "location": "import",
            "path": "./model/multi-selector-level-section"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "section of a level"
      }
    },
    "highlight": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "This string is highlighted in the labels"
      },
      "attribute": "highlight",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "nodeSelectionChanged",
      "name": "nodeSelectionChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event to notify, when checkbox of element in list get selected"
      },
      "complexType": {
        "original": "NodeSelectionChangedEvent",
        "resolved": "NodeSelectionChangedEvent",
        "references": {
          "NodeSelectionChangedEvent": {
            "location": "import",
            "path": "../../model"
          }
        }
      }
    }, {
      "method": "nodeActiveChanged",
      "name": "nodeActiveChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Event to notify when active state of element is changed."
      },
      "complexType": {
        "original": "NodeActiveChangedEvent",
        "resolved": "NodeActiveChangedEvent",
        "references": {
          "NodeActiveChangedEvent": {
            "location": "import",
            "path": "../../model"
          }
        }
      }
    }]; }
}

