/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { Component, h, Host, Method, Prop, Watch } from '@stencil/core';
import { Overlay } from '@spectrum-web-components/overlay';
export class BciOverlay {
  constructor() {
    /**
     * Configuration
     */
    this.config = {
      placement: 'bottom-start',
    };
    this._shouldReopen = false;
  }
  onConfigChange(newConfig, oldConfig) {
    if (this.close !== undefined && !!oldConfig && newConfig.placement !== oldConfig.placement) {
      this._shouldReopen = true;
      this.hide();
    }
  }
  componentDidRender() {
    if (this._shouldReopen) {
      this._shouldReopen = false;
      setTimeout(() => this.show(), 250);
    }
  }
  /**
   * try to show the overlay and return the current visibility state
   */
  async show() {
    if (this.close === undefined && this.host && this.dialog) {
      this.close = await Overlay.open(this.host, 'click', this.dialog, this.config);
      return true;
    }
    return false;
  }
  /**
   * update the overlay, e.g. to fix positioning
   */
  async update() {
    Overlay.update();
  }
  /**
   * try to hide the overlay and return the current visibility state
   */
  async hide() {
    var _a;
    if (this.close !== undefined) {
      (_a = this.close) === null || _a === void 0 ? void 0 : _a.call(this);
      this.close = undefined;
    }
    return false;
  }
  render() {
    return (h(Host, null,
      h("template", null,
        h("slot", null))));
  }
  static get is() { return "bci-overlay"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["overlay.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["overlay.css"]
  }; }
  static get properties() { return {
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "OverlayOptions",
        "resolved": "{ delayed?: boolean; placement?: Placement; offset?: number; receivesFocus?: \"auto\"; notImmediatelyClosable?: boolean; abortPromise?: Promise<boolean>; virtualTrigger?: VirtualTrigger; }",
        "references": {
          "OverlayOptions": {
            "location": "import",
            "path": "@spectrum-web-components/overlay"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Configuration"
      },
      "defaultValue": "{\n    placement: 'bottom-start',\n  }"
    },
    "host": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "HTMLElement",
        "resolved": "HTMLElement",
        "references": {
          "HTMLElement": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The dialog will be positioned relative to this element"
      }
    },
    "dialog": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "HTMLElement",
        "resolved": "HTMLElement",
        "references": {
          "HTMLElement": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "This will be shown in the dialog"
      }
    }
  }; }
  static get methods() { return {
    "show": {
      "complexType": {
        "signature": "() => Promise<boolean>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<boolean>"
      },
      "docs": {
        "text": "try to show the overlay and return the current visibility state",
        "tags": []
      }
    },
    "update": {
      "complexType": {
        "signature": "() => Promise<void>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "update the overlay, e.g. to fix positioning",
        "tags": []
      }
    },
    "hide": {
      "complexType": {
        "signature": "() => Promise<boolean>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<boolean>"
      },
      "docs": {
        "text": "try to hide the overlay and return the current visibility state",
        "tags": []
      }
    }
  }; }
  static get watchers() { return [{
      "propName": "config",
      "methodName": "onConfigChange"
    }]; }
}

