/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { Component, h, Listen, Element } from '@stencil/core';
import { NotificationClass } from '../header-message-icon/header-message-icon.interface';
import { MDCSnackbar } from '@material/snackbar';
import { translate } from '../../utils/utils';
export class ToasterComponent {
  constructor() {
    this.messages = [];
  }
  componentDidRender() {
    this.snackbar = new MDCSnackbar(this.el.shadowRoot.querySelector('.bci-portal-toaster'));
    this.snackbar.listen('MDCSnackbar:closed', () => {
      if (this.messages.length > 0) {
        this.show(this.messages.shift());
      }
    });
  }
  onMessageCreated(event) {
    if (this.snackbar.isOpen || this.messages.length > 0) {
      this.messages.push(event.detail);
      return;
    }
    this.show(event.detail);
  }
  show(message) {
    this.activeMessage = message;
    this.el.shadowRoot.querySelector('#bci-portal-toaster-message-icon').className = this.determineClassIcon(message);
    this.el.shadowRoot.querySelector('.mdc-snackbar__action').className = this.determineActionButtonClass(message);
    this.snackbar.labelText = message.title;
    this.snackbar.actionButtonText = message.link ? translate('goTo') : '';
    this.snackbar.open();
  }
  action() {
    if (this.activeMessage.link) {
      window.location.href = this.activeMessage.link;
    }
  }
  determineClassIcon(message) {
    const icon = 'bosch-ic bosch-ic';
    switch (message.class) {
      case NotificationClass.Error:
        return `${icon}-alert-error`;
      case NotificationClass.Success:
        return `${icon}-alert-success`;
      case NotificationClass.Warning:
        return `${icon}-alert-warning`;
      default:
        return `${icon}-info-i`;
    }
  }
  determineActionButtonClass(message) {
    const className = 'mdc-button mdc-snackbar__action';
    return message.link ? className : className + ' mdc-snackbar__action_hidden';
  }
  render() {
    return (h("div", { class: "mdc-snackbar bci-portal-toaster" },
      h("div", { class: "mdc-snackbar__surface" },
        h("div", { class: "bci-portal-icon" },
          h("span", { class: "bosch-ic bosch-ic-info-i", id: "bci-portal-toaster-message-icon" })),
        h("div", { class: "mdc-snackbar__label", role: "status" }),
        h("div", { class: "mdc-snackbar__actions" },
          h("button", { class: "mdc-button mdc-snackbar__action", "data-test": "webcore.webcomponents.toaster.action.button", onClick: () => this.action() },
            h("span", { class: "mdc-button__label bci-portal-button" }))))));
  }
  static get is() { return "bci-portal-toaster"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["toaster.component.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["toaster.component.css"]
  }; }
  static get elementRef() { return "el"; }
  static get listeners() { return [{
      "name": "bci.portal.message.created",
      "method": "onMessageCreated",
      "target": "window",
      "capture": false,
      "passive": false
    }]; }
}

