/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/**
 * Copyright (C) 2021. Robert Bosch GmbH Copyright (C) 2021. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
export class FacilitySelectionContoller {
  constructor(_selectedItemPerLevel = [], _checkedItemPerLevel = [], _selectedItems = new Set(), _checkedItems = new Set(), _indeterminateItems = new Map(), _enableMultiSelection = false) {
    this._selectedItemPerLevel = _selectedItemPerLevel;
    this._checkedItemPerLevel = _checkedItemPerLevel;
    this._selectedItems = _selectedItems;
    this._checkedItems = _checkedItems;
    this._indeterminateItems = _indeterminateItems;
    this._enableMultiSelection = _enableMultiSelection;
    this._selectedItemPerLevel = [..._selectedItemPerLevel];
    this._checkedItemPerLevel = [..._checkedItemPerLevel];
    this._selectedItems = new Set(_selectedItems);
    this._checkedItems = new Set(_checkedItems);
    this._indeterminateItems = new Map(_indeterminateItems);
    this._enableMultiSelection = _enableMultiSelection;
  }
  get selectedItemPerLevel() {
    return this._selectedItemPerLevel;
  }
  get checkedItemPerLevel() {
    return this._checkedItemPerLevel;
  }
  get checkedItems() {
    return this._checkedItems;
  }
  get selectedItems() {
    return this._selectedItems;
  }
  get indeterminateItems() {
    return this._indeterminateItems;
  }
  get numberOfCheckedItems() {
    return this._checkedItems.size;
  }
  get checkedItemList() {
    return [...this.checkedItems];
  }
  get isMultiSelectEnabled() {
    return this._enableMultiSelection;
  }
  set isMultiSelectEnabled(enableMultiSelection) {
    this._enableMultiSelection = enableMultiSelection;
  }
  getSelectedItemAtLevel(level) {
    return this._selectedItemPerLevel[level];
  }
  isSelected(item) {
    return this._selectedItems.has(item.id);
  }
  isChecked(item) {
    return this._checkedItems.has(item.id);
  }
  isIndeterminate(item) {
    return this._indeterminateItems.has(item.id);
  }
  selectItem(item, level) {
    if (level <= this._selectedItemPerLevel.length - 1) {
      this._selectedItemPerLevel = [...this._selectedItemPerLevel.slice(0, level)];
    }
    this._selectedItemPerLevel = [...this._selectedItemPerLevel, item];
    this._selectedItems.add(item.id);
  }
  deselectItem(item) {
    const index = this._selectedItemPerLevel.findIndex((selectedItem) => item.id === selectedItem.id);
    this._selectedItemPerLevel = [...this._selectedItemPerLevel.slice(0, index)];
    this._selectedItems.delete(item.id);
  }
  checkItem(item, level) {
    if (!this.isMultiSelectEnabled) {
      this.clearCheckedItems();
    }
    this._checkedItemPerLevel[level] = [...(this._checkedItemPerLevel[level] || []), item];
    this._checkedItems.add(item.id);
  }
  uncheckItem(item, level) {
    const index = (this._checkedItemPerLevel[level] || []).findIndex((checkedItem) => item.id === checkedItem.id);
    if (index > -1) {
      this._checkedItemPerLevel[level].splice(index, 1);
      this._checkedItemPerLevel[level] = [...(this._checkedItemPerLevel[level] || [])];
      this._checkedItems.delete(item.id);
    }
  }
  markAsIndeterminate(item) {
    if (this.isIndeterminate(item)) {
      this._indeterminateItems.set(item.id, this._indeterminateItems.get(item.id) + 1);
    }
    else {
      this._indeterminateItems.set(item.id, 1);
    }
  }
  unmarkAsIndeterminate(item) {
    if (this.isIndeterminate(item) && this._indeterminateItems.get(item.id) === 1) {
      this._indeterminateItems.delete(item.id);
    }
    else if (this.isIndeterminate(item)) {
      this._indeterminateItems.set(item.id, this._indeterminateItems.get(item.id) - 1);
    }
  }
  clearCheckedItems() {
    this._checkedItemPerLevel = [];
    this._checkedItems.clear();
    this._indeterminateItems.clear();
  }
  clear() {
    this._selectedItemPerLevel = [];
    this._checkedItemPerLevel = [];
    this._selectedItems.clear();
    this._checkedItems.clear();
    this._indeterminateItems.clear();
  }
}

