/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
/*
 * Copyright (C) 2019 Robert Bosch GmbH Copyright (C) 2019 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.
 */
import { createStore } from '@stencil/store';
import { DEFAULT_LOCALE } from './localization';
const { state, onChange } = createStore({
  language: DEFAULT_LOCALE.language,
  dateFormat: DEFAULT_LOCALE.dateFormat,
  timeFormat: DEFAULT_LOCALE.timeFormat,
  translations: {},
  languageListenerActive: false,
  isStateSet: false,
});
export default state;
// Needed when text is not directly translated in the dom
export function listenToLanguageChange(callback) {
  onChange('language', () => callback());
}
export async function setLocale() {
  if (state.isStateSet) {
    return;
  }
  setupLangChangeListener();
  return Promise.all([getLanguage(), getDateFormat(), getTimeFormat()]).then(async ([language, dateFormat, timeFormat]) => {
    state.isStateSet = true;
    state.language = language;
    state.dateFormat = dateFormat;
    state.timeFormat = timeFormat;
    return;
  });
}
/**
 * Gets user language from the document lang attribute
 * Or from the portal user settings global object
 */
async function getLanguage() {
  let language = document.documentElement.getAttribute('lang');
  if (!language || language === 'undefined') {
    try {
      language = await getPortalContext().getSCSUserSetting('bci.system.language');
    }
    catch (_a) {
      language = DEFAULT_LOCALE.language;
    }
  }
  return language;
}
/**
 * Gets dateformat string from global user settings object
 * Or takes default
 */
async function getDateFormat() {
  try {
    return await getPortalContext().getSCSUserSetting('bci.system.dateformat');
  }
  catch (_a) {
    return DEFAULT_LOCALE.dateFormat;
  }
}
/**
 * Gets timeformat string from global user settings object
 * Or takes default
 */
async function getTimeFormat() {
  try {
    return await getPortalContext().getSCSUserSetting('bci.system.timeformat');
  }
  catch (_a) {
    return DEFAULT_LOCALE.timeFormat;
  }
}
export function setupLangChangeListener() {
  if (state.languageListenerActive) {
    return;
  }
  const observer = new MutationObserver((mutations) => {
    // If the language attribute has changed
    if (mutations.filter((item) => item.attributeName === 'lang').length > 0) {
      state.language = document.documentElement.getAttribute('lang');
    }
  });
  observer.observe(document.documentElement, { attributes: true });
  state.languageListenerActive = true;
}
function getPortalContext() {
  return window['BCIPortal'];
}

