/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { p as proxyCustomElement, H, h, b as Host } from './p-6fc5b736.js';
import { d as setLocale } from './p-d4c86b19.js';
import { d as defineCustomElement$1 } from './p-184dda00.js';

const multiSelectorSearchLabelCss = "/*!\n  *  Copyright (C) 2017 Robert Bosch GmbH Copyright (C) 2017 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n *//*!\n  *  Copyright (C) 2022 Robert Bosch GmbH Copyright (C) 2022 Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved.\n */:host bci-multi-selector-search-label{display:flex;text-overflow:ellipsis;height:1.5em;overflow:hidden}:host bci-multi-selector-search-label .breadcrumbs{display:flex;justify-content:flex-start;flex-shrink:1;flex-basis:auto;overflow:hidden}:host bci-multi-selector-search-label .breadcrumb{display:inline;box-sizing:border-box;text-overflow:ellipsis;overflow:hidden;white-space:nowrap;flex-shrink:999999999;flex-grow:1;flex-basis:auto}:host bci-multi-selector-search-label .breadcrumb:nth-child(2){min-width:32px;flex-shrink:999999;flex-grow:1}:host bci-multi-selector-search-label .breadcrumb:first-child,:host bci-multi-selector-search-label .breadcrumb:last-child{flex-shrink:1;flex-grow:0;flex-basis:auto}:host bci-multi-selector-search-label .breadcrumb-separator{color:#7d8389}:host bci-multi-selector-search-label .breadcrumb-separator bci-icon{font-size:1em}";

const MultiSelectorSearchLabel = /*@__PURE__*/ proxyCustomElement(class extends H {
  constructor() {
    super();
    this.__registerHost();
    this.breadcrumbTrails = [];
  }
  async componentWillLoad() {
    await setLocale();
    this.computeBreadcrumbs(this.selections);
  }
  computeBreadcrumbs(selections) {
    const selectionsByRootNodeId = selections.reduce((acc, selection) => {
      const key = '' + selection[0].id;
      acc[key] = acc[key] || [];
      acc[key].push(selection);
      return acc;
    }, {});
    this.breadcrumbTrails = Object.values(selectionsByRootNodeId).map((selections) => {
      // find longest common prefix
      const [firstSelection, ...otherSelections] = selections;
      const labels = firstSelection
        .map((node, index) => otherSelections.every((selection) => selection.length > index && selection[index].id === node.id) ? node.label : null)
        .filter((label) => !!label);
      // if this longest common prefix breadcrumb trail represents more than one selected element, add the number of elements represented to the end
      if (selections.length > 1) {
        labels[labels.length - 1] += ` (${selections.length})`;
      }
      return labels;
    });
  }
  render() {
    return (h(Host, null, this.breadcrumbTrails
      .map((breadcrumbs) => this.renderBreadcrumbs(breadcrumbs))
      .map((element, index) => [index > 0 ? h("span", null, ",\u00A0") : '', element])));
  }
  renderBreadcrumb(breadcrumb, index) {
    return (h("span", { class: "breadcrumb" }, index > 0 ? (h("span", { class: "breadcrumb-separator" }, h("bci-icon", { name: "forward-right" }), "\u2009")) : (''), breadcrumb));
  }
  renderBreadcrumbs(breadcrumbs) {
    const [first, ...rest] = breadcrumbs;
    const last = rest.pop();
    return (h("span", { class: "breadcrumbs" }, this.renderBreadcrumb(first, 0), rest.map((breadcrumb, index) => this.renderBreadcrumb(breadcrumb, index + 1)), !!last ? this.renderBreadcrumb(last, breadcrumbs.length - 1) : ''));
  }
  static get watchers() { return {
    "selections": ["computeBreadcrumbs"]
  }; }
  static get style() { return multiSelectorSearchLabelCss; }
}, [0, "bci-multi-selector-search-label", {
    "selections": [16],
    "breadcrumbTrails": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["bci-multi-selector-search-label", "bci-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "bci-multi-selector-search-label":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, MultiSelectorSearchLabel);
      }
      break;
    case "bci-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { MultiSelectorSearchLabel as M, defineCustomElement as d };

