/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
class WidthObserver {
  constructor(element, callbacks, considerPaddings = true) {
    this.element = element;
    this.callbacks = callbacks;
    this.considerPaddings = considerPaddings;
    this.breakpointVP1 = 480;
    this.breakpointVP2 = 768;
    this.containerPaddingForPhone = 14;
    this.containerPaddingForTablet = 16;
    this.desktopBreakpoint = this.breakpointVP2 - 2 * this.containerPaddingForTablet;
    this.tabletBreakpoint = this.breakpointVP1 - 2 * this.containerPaddingForPhone;
    this.resizeObserver = new ResizeObserver(() => this.updateViewport());
    this.isObserving = false;
  }
  connect() {
    this.isObserving = true;
    this.resizeObserver.observe(this.element);
    this.updateViewport();
  }
  disconnect() {
    this.isObserving = false;
    this.resizeObserver.unobserve(this.element);
  }
  isConnected() {
    return this.isObserving;
  }
  get currentViewport() {
    return this._currentViewport;
  }
  updateViewport() {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const availableWidth = this.element.clientWidth;
    // it is 0 if the overlay is not visible
    if (availableWidth === 0) {
      return;
    }
    const showVP1 = availableWidth <= (this.considerPaddings ? this.tabletBreakpoint : this.breakpointVP1);
    const showVP2 = availableWidth <= (this.considerPaddings ? this.desktopBreakpoint : this.breakpointVP2);
    if (showVP1) {
      if (this._currentViewport !== 'vp1') {
        (_b = (_a = this.callbacks).onVp1) === null || _b === void 0 ? void 0 : _b.call(_a);
        this._currentViewport = 'vp1';
      }
    }
    else if (showVP2) {
      if (this._currentViewport !== 'vp2') {
        (_d = (_c = this.callbacks).onVp2) === null || _d === void 0 ? void 0 : _d.call(_c);
        this._currentViewport = 'vp2';
      }
    }
    else {
      if (this._currentViewport !== 'vp3') {
        (_f = (_e = this.callbacks).onVp3) === null || _f === void 0 ? void 0 : _f.call(_e);
        this._currentViewport = 'vp3';
      }
    }
    (_h = (_g = this.callbacks).onChange) === null || _h === void 0 ? void 0 : _h.call(_g, availableWidth);
  }
}

export { WidthObserver as W };

