/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { EventEmitter } from '../../../stencil-public-runtime';
import { DatesObject, DaySelectedObject, ArrowClickObject, YearMonthSelectedObject } from '../datepicker/datepicker.models';
import { DateTime, Template, TemplateGroup } from '../datetime-picker.interface';
import { DatePickerConfig, SelectionChanged, TemplateEvent, TimePickerConfig } from '../model';
import { FormattingService } from '../service';
import { DateService } from '../service/date-service';
import { TimeSelectedObject } from '../timepicker/timepicker.model';
declare type SelectionStep = 'year' | 'month';
export declare class DateTimeDialog {
  /**
   * This id reused within the children ids
   */
  dateTimePickerId: string;
  /**
   * Pass through of the current time state
   */
  datePickerInputObj: DateTime;
  /** Which templates should be displayed */
  templatesList: Array<Template | TemplateGroup>;
  /** Whether the "Templates"-Button should be disabled */
  templatesDisabled: boolean;
  /** Which parts of the datepicker should be hidden */
  hide?: 'calendar' | 'time';
  /**
   * Contains the settings for the date picker
   */
  datePickerConfig: DatePickerConfig;
  /**
   * Contains the settings for the time picker
   */
  timePickerConfig: TimePickerConfig;
  /**
   * Emits if any child value changes
   */
  selectionChanged: EventEmitter<SelectionChanged>;
  showTemplates: boolean;
  /**
   * Case null: Year/Month Selection closed.
   * Case 'year': Year Selection active.
   * Case 'month': Month Selection active.
   */
  yearMonthSelectionStep: SelectionStep;
  /** Tracks how often the user switched pages in the year selection */
  yearSelectionPageOffset: number;
  /**
   * Object that stores the data of the currently displayed month which the user can select a date from.
   * @field calendarDate Today's date
   * @field calendarDateYear The currently selected year
   * @field calendarDateMonth The currently selected month
   * @field selectedDate The currently selected date
   */
  dateObj: {
    calendarDate: string;
    calendarDateYear: number;
    calendarDateMonth: number;
    selectedDate: string;
  };
  /** Object to keep track of the currently selected date range */
  datesObj: DatesObject;
  private templatesElement?;
  /**
   * Optional - inject the FormattingService instance
   */
  formatService: FormattingService;
  /**
   * Optional - inject the DateService instance
   */
  dateService: DateService;
  /** Handler for toggling the dialog */
  toggleDialogHandler: () => void;
  private emitSelectionChanged;
  onTemplateUpdate({ detail: { firstEmit, timeStamp, id } }: CustomEvent<TemplateEvent>): void;
  timeSelectedHandler({ detail: data }: CustomEvent<TimeSelectedObject>): void;
  showTimeRange(): void;
  /**
   * Clears internal timer and resets selected template
   */
  close(): Promise<void>;
  /**
   * Closes the Year/Month Selection
   */
  closeYearMonthSelection(): Promise<void>;
  private showTemplate;
  toggleShowYearMonthSelectionHandler(event: CustomEvent<{
    newState: boolean;
  }>): void;
  arrowClickedHandler(event: CustomEvent<ArrowClickObject>): void;
  private handleMonthChangeOnArrowClick;
  yearMonthSelectedHandler(event: CustomEvent<YearMonthSelectedObject>): void;
  singleDateSelectedHandler(event: CustomEvent<DaySelectedObject>): void;
  rangeDateSelectedHandler(event: CustomEvent<DaySelectedObject>): void;
  userInputDate(newValue: any): void;
  componentWillLoad(): Promise<void>;
  private applyTemplate;
  render(): any;
}
export {};

