/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { CheckedState, SelectionMode } from '../../model';
import { NodePath, RootDataSource } from '../../model/multi-selector.interface';
import { Level } from '../../multi-selector-overlay/multi-selector-level/model';
import { OnInvalidSelection } from '../../multi-selector-overlay/multi-selector-tree/service/tree-filter';
import { OnActiveChange, OnClearSearch } from '../../multi-selector-overlay/multi-selector-tree/service/tree-manager';
import { OnLoadingChange } from '../../multi-selector-overlay/multi-selector-tree/service/tree-manager/tree-manager.interfaces';
import { OnSelectionChange } from '../../multi-selector-overlay/multi-selector-tree/service/tree-selection';
export declare class MultiSelectorManager {
  private onActiveChange;
  private onSelectionChange;
  private onClearSearch;
  private onInvalidSelection;
  private onLoadingChange;
  private _activeLevels;
  private _tree?;
  private _selectionService;
  private _filterService;
  private loadingHandler;
  private dataSource;
  private _focussedNode;
  /**
   * initiate class and load the initial root level of the tree
   * @param dataSource
   * @param singleSelectMode
   * @param onActiveChange Provide a function that is called whenever the active levels change
   */
  constructor(dataSource: RootDataSource, onActiveChange: OnActiveChange, onSelectionChange: OnSelectionChange, onClearSearch: OnClearSearch, onInvalidSelection: OnInvalidSelection, onLoadingChange: OnLoadingChange, initialSelection?: NodePath[], selectionMode?: SelectionMode);
  getFilter(): string;
  updateFilter(filter: string): void;
  resetSelection(notify?: boolean): void;
  private updateSelection;
  updateSelectionMode(selectionMode: SelectionMode): void;
  setSelectionStateOfNodeByPath(changedNode: NodePath, newState: CheckedState): void;
  initiateSelections(selections: NodePath[]): void;
  get isLoading(): boolean;
  getActiveLevels(): Level[];
  arrowLeftPressed(): Promise<void>;
  arrowRightPressed(): Promise<void>;
  arrowUpPressed(): void;
  arrowDownPressed(): void;
  mouseDown(): void;
  spacePressed(): void;
  private initiateFocussedNode;
  /**
   * takes care of updating the references of class variables if a refresh/clone of the tree happened
   */
  private refreshFocussedNodeReference;
  isFirstElementFocussed(): boolean;
  resetFocus(): void;
  private getLevelOfFocussedNode;
  private removeFocusOfNode;
  private setFocusedNodeByPath;
  /**
   * sets the active State of a Node by its NodePath (last element of NodePath is the effected Node)
   * @param path
   * @param active
   * @returns
   */
  setActiveStateOfNodeByPath(path: NodePath, active: boolean): Promise<void>;
  /**
   * sets a level to inactive by setting its parent and all children to inactive
   * @param level
   */
  deactivateLevel(level: Level): void;
  private getLastActiveLevel;
  /**
   * updates the active Levels and notifies about a refresh of the activeLevels
   */
  private updateActiveLevels;
  private notifyCallback;
  private mapNodesToMultiSelectorTreeNodes;
  /**
   * updates the active levels according to the given Path of the changed node
   * @param effectedNode represents the the node that is gonna change the node state
   * @param active the new state of the node (true=selected=open, false=unselected=close)
   * @returns reference to the selected node
   */
  private updateActiveStateOfNode;
  /**
   * loads the children of a node if already loaded returns the loaded children
   * @param node
   * @returns
   */
  private loadChildrenOfNode;
  private handleLoadedNodes;
  private invokeAsync;
  get selections(): NodePath[];
}

