/* Copyright (C) 2023. Robert Bosch GmbH Copyright (C) 2023. Robert Bosch Manufacturing Solutions GmbH, Germany. All rights reserved. */
import { EventEmitter } from '../../stencil-public-runtime';
import { PageEvent } from './paginator.interface';
export declare class Paginator {
  /** Number of items to display on a page. By default set to 10. */
  pageSize: number;
  /** The set of provided page size options to display to the user. */
  pageSizeOptions: string;
  /** The length of the total number of items that are being paginated. Defaulted to 0. */
  length: number;
  /** The zero-based page index of the displayed list of items. Defaulted to 0. */
  pageIndex: number;
  /** If page size option is not needed */
  showPageSizeSelector: boolean;
  /** If page index calculation is not needed then set to true */
  pageIndexCalculationOff: boolean;
  /** Set to true when used inside a dialog container to avoid overflow */
  insideDialogContainer: boolean;
  /** Event emitted when the paginator changes the page size or page index. */
  page: EventEmitter<PageEvent>;
  paginatorInput: {
    length: number;
    pageIndex: number;
    pageSize: number;
    pageSizeOptions: any[];
    showPageSizeSelector: boolean;
  };
  pages: any[];
  private selectElement;
  private mdcSelect;
  private menuElement;
  private mdcMenu;
  private pagesNumber;
  private previousPageIndex;
  private previousPageSize;
  private isFirstLoad;
  private isPageSizeUpdate;
  watchLengthHandler(newValue: number): void;
  watchPageSizeOptionsHandler(newValue: string): void;
  watchPageIndex(newValue: number): void;
  watchShowPageSizeSelector(newValue: boolean): void;
  watchPageSize(newValue: number): void;
  clickHandler(ev: MouseEvent): void;
  componentWillLoad(): Promise<void>;
  componentDidLoad(): void;
  disconnectedCallback(): void;
  render(): any;
  private shouldHidePageSizeSelector;
  private shouldHidePageIndexSelector;
  private renderPageIndexSelector;
  private updatePageSize;
  private updatePageIndex;
  private previousPage;
  private nextPage;
  private recalculatePages;
  private isAtFirstPage;
  private isAtLastPage;
  private emitPageEvent;
  private getSelectedMenuItemClass;
  private getPageButtonClass;
  private getEllipsesElement;
  private getPageButtonElement;
  private getPredicateBasedRender;
  private positionBasedRender;
  private renderMobilePages;
  private renderPageSizeSelector;
}

